Index: mscore/mscore/mscore/file.cpp
===================================================================
--- mscore/mscore/mscore/file.cpp	(revision 3782)
+++ mscore/mscore/mscore/file.cpp	(working copy)
@@ -1569,8 +1569,10 @@
             const QList<Page*> pl = pages();
             int pages = pl.size();
 
-            int fromPage = printer->fromPage() - 1;
-            int toPage   = printer->toPage() - 1;
+//            int fromPage = printer->fromPage() - 1;
+//            int toPage   = printer->toPage() - 1;
+            int fromPage = printer->fromPage() - 1 - pageFormat()->_pageOffset;
+            int toPage   = printer->toPage() - 1 - pageFormat()->_pageOffset;
             if (fromPage < 0)
                   fromPage = 0;
             if ((toPage < 0) || (toPage >= pages))
Index: mscore/mscore/mscore/page.cpp
===================================================================
--- mscore/mscore/mscore/page.cpp	(revision 3782)
+++ mscore/mscore/mscore/page.cpp	(working copy)
@@ -48,6 +48,7 @@
    _no(0), _pageNo(0), _copyright(0)
       {
       }
+
 Page::~Page()
       {
       delete _pageNo;
@@ -92,6 +93,13 @@
       }
 
 //---------------------------------------------------------
+//   isOdd
+//---------------------------------------------------------
+bool Page::isOdd() const
+      {
+      return (_no+1 + _score->pageFormat()->_pageOffset) & 1;
+      }
+//---------------------------------------------------------
 //   appendSystem
 //---------------------------------------------------------
 
@@ -119,7 +127,7 @@
       setbbox(QRectF(0.0, 0.0, loWidth(), loHeight()));
 
       // add page number
-      int n = no() + 1 + _score->_pageOffset;
+      int n = no() + 1 + _score->pageFormat()->_pageOffset;
       if (score()->styleB(ST_showPageNumber) && ((n > 1) || score()->styleB(ST_showPageNumberOne))) {
             int subtype = (n & 1) ? TEXT_PAGE_NUMBER_ODD : TEXT_PAGE_NUMBER_EVEN;
             int style   = (n & 1) ? TEXT_STYLE_PAGE_NUMBER_ODD : TEXT_STYLE_PAGE_NUMBER_EVEN;
@@ -282,7 +290,8 @@
    oddTopMargin(10.0 / INCH),
    oddBottomMargin(20.0 / INCH),
    landscape(preferences.landscape),
-   twosided(preferences.twosided)
+   twosided(preferences.twosided),
+   _pageOffset(0)
       {
       }
 
@@ -389,6 +398,8 @@
                   size = paperSizeNameToIndex("Custom");
                   _width = val.toDouble() * .5 / PPI;
                   }
+            else if (tag == "page-offset")
+                  _pageOffset = val.toInt();
             else
                   domError(e);
             }
@@ -508,6 +519,8 @@
       xml.tag("bottom-margin", oddBottomMargin * t);
       xml.etag();
 
+      xml.tag("page-offset", _pageOffset);
+
       xml.etag();
       }
 
Index: mscore/mscore/mscore/pagesettings.cpp
===================================================================
--- mscore/mscore/mscore/pagesettings.cpp	(revision 3782)
+++ mscore/mscore/mscore/pagesettings.cpp	(working copy)
@@ -180,6 +180,9 @@
       connect(evenPageRightMargin, SIGNAL(valueChanged(double)), SLOT(ermChanged(double)));
       connect(pageGroup, SIGNAL(activated(int)), SLOT(pageFormatSelected(int)));
       connect(spatiumEntry, SIGNAL(valueChanged(double)), SLOT(spatiumChanged(double)));
+
+      connect(pageOffsetEntry, SIGNAL(valueChanged(int)), SLOT(pageOffsetChanged(int)));
+
       }
 
 //---------------------------------------------------------
@@ -201,6 +204,7 @@
       spatiumEntry->blockSignals(true);
       pageWidth->blockSignals(true);
       pageHeight->blockSignals(true);
+      pageOffsetEntry->blockSignals(true);
 
       const char* suffix = mm ? "mm" : "in";
       oddPageTopMargin->setSuffix(suffix);
@@ -257,6 +261,8 @@
       landscape->setChecked(pf->landscape);
       twosided->setChecked(pf->twosided);
 
+      pageOffsetEntry->setValue(pf->_pageOffset + 1);
+
       pageWidth->blockSignals(false);
       pageHeight->blockSignals(false);
       oddPageTopMargin->blockSignals(false);
@@ -268,6 +274,7 @@
       evenPageLeftMargin->blockSignals(false);
       evenPageRightMargin->blockSignals(false);
       spatiumEntry->blockSignals(false);
+      pageOffsetEntry->blockSignals(false);
       }
 
 //---------------------------------------------------------
@@ -336,6 +343,7 @@
       pf.oddRightMargin   = oddPageRightMargin->value() * f;
       pf.landscape        = landscape->isChecked();
       pf.twosided         = twosided->isChecked();
+      pf._pageOffset      = pageOffsetEntry->value() - 1;
 
       double sp = spatiumEntry->value() * f1;
 
@@ -484,6 +492,17 @@
       }
 
 //---------------------------------------------------------
+//   pageOffsetChanged
+//---------------------------------------------------------
+
+void PageSettings::pageOffsetChanged(int val)
+      {
+      PageFormat* f = preview->score()->pageFormat();
+      f->_pageOffset = val - 1;
+      preview->layout();
+      }
+
+//---------------------------------------------------------
 //   pageHeightChanged
 //---------------------------------------------------------
 
Index: mscore/mscore/mscore/pagesettings.h
===================================================================
--- mscore/mscore/mscore/pagesettings.h	(revision 3782)
+++ mscore/mscore/mscore/pagesettings.h	(working copy)
@@ -60,6 +60,7 @@
       void spatiumChanged(double val);
       void pageHeightChanged(double);
       void pageWidthChanged(double);
+      void pageOffsetChanged(int val);
 
    public:
       PageSettings(QWidget* parent = 0);
Index: mscore/mscore/mscore/pagesettings.ui
===================================================================
--- mscore/mscore/mscore/pagesettings.ui	(revision 3782)
+++ mscore/mscore/mscore/pagesettings.ui	(working copy)
@@ -1,556 +1,585 @@
-<ui version="4.0" >
- <class>PageSettingsBase</class>
- <widget class="QDialog" name="PageSettingsBase" >
-  <property name="geometry" >
-   <rect>
-    <x>0</x>
-    <y>0</y>
-    <width>777</width>
-    <height>436</height>
-   </rect>
-  </property>
-  <property name="windowTitle" >
-   <string>MuseScore: Page Settings</string>
-  </property>
-  <layout class="QGridLayout" >
-   <property name="margin" >
-    <number>8</number>
-   </property>
-   <property name="spacing" >
-    <number>6</number>
-   </property>
-   <item row="0" column="2" >
-    <widget class="QGroupBox" name="previewGroup" >
-     <property name="sizePolicy" >
-      <sizepolicy vsizetype="Expanding" hsizetype="Expanding" >
-       <horstretch>0</horstretch>
-       <verstretch>0</verstretch>
-      </sizepolicy>
-     </property>
-     <property name="title" >
-      <string>Preview</string>
-     </property>
-    </widget>
-   </item>
-   <item row="1" column="0" colspan="3" >
-    <layout class="QHBoxLayout" >
-     <property name="spacing" >
-      <number>6</number>
-     </property>
-     <property name="margin" >
-      <number>0</number>
-     </property>
-     <item>
-      <spacer>
-       <property name="orientation" >
-        <enum>Qt::Horizontal</enum>
-       </property>
-       <property name="sizeHint" stdset="0" >
-        <size>
-         <width>131</width>
-         <height>31</height>
-        </size>
-       </property>
-      </spacer>
-     </item>
-     <item>
-      <widget class="QPushButton" name="buttonApply" >
-       <property name="text" >
-        <string>Apply</string>
-       </property>
-      </widget>
-     </item>
-     <item>
-      <widget class="QPushButton" name="buttonOk" >
-       <property name="text" >
-        <string>OK</string>
-       </property>
-      </widget>
-     </item>
-     <item>
-      <widget class="QPushButton" name="buttonCancel" >
-       <property name="text" >
-        <string>Cancel</string>
-       </property>
-      </widget>
-     </item>
-    </layout>
-   </item>
-   <item row="0" column="0" >
-    <layout class="QVBoxLayout" >
-     <property name="spacing" >
-      <number>6</number>
-     </property>
-     <property name="margin" >
-      <number>0</number>
-     </property>
-     <item>
-      <widget class="QGroupBox" name="groupBox" >
-       <property name="title" >
-        <string>Page Size</string>
-       </property>
-       <layout class="QGridLayout" >
-        <property name="margin" >
-         <number>8</number>
-        </property>
-        <property name="spacing" >
-         <number>6</number>
-        </property>
-        <item row="1" column="1" >
-         <widget class="QDoubleSpinBox" name="pageWidth" >
-          <property name="sizePolicy" >
-           <sizepolicy vsizetype="Fixed" hsizetype="Minimum" >
-            <horstretch>0</horstretch>
-            <verstretch>0</verstretch>
-           </sizepolicy>
-          </property>
-          <property name="maximum" >
-           <double>2000.000000000000000</double>
-          </property>
-         </widget>
-        </item>
-        <item row="2" column="1" >
-         <widget class="QDoubleSpinBox" name="pageHeight" >
-          <property name="sizePolicy" >
-           <sizepolicy vsizetype="Fixed" hsizetype="Minimum" >
-            <horstretch>0</horstretch>
-            <verstretch>0</verstretch>
-           </sizepolicy>
-          </property>
-          <property name="maximum" >
-           <double>2000.000000000000000</double>
-          </property>
-         </widget>
-        </item>
-        <item row="4" column="0" colspan="2" >
-         <widget class="QCheckBox" name="twosided" >
-          <property name="text" >
-           <string>Two Sided</string>
-          </property>
-         </widget>
-        </item>
-        <item row="3" column="0" colspan="2" >
-         <widget class="QCheckBox" name="landscape" >
-          <property name="text" >
-           <string>Landscape</string>
-          </property>
-         </widget>
-        </item>
-        <item row="2" column="0" >
-         <widget class="QLabel" name="label_3" >
-          <property name="text" >
-           <string>Height</string>
-          </property>
-          <property name="textFormat" >
-           <enum>Qt::PlainText</enum>
-          </property>
-          <property name="buddy" >
-           <cstring>pageHeight</cstring>
-          </property>
-         </widget>
-        </item>
-        <item row="1" column="0" >
-         <widget class="QLabel" name="label_2" >
-          <property name="text" >
-           <string>Width</string>
-          </property>
-          <property name="textFormat" >
-           <enum>Qt::PlainText</enum>
-          </property>
-          <property name="buddy" >
-           <cstring>pageWidth</cstring>
-          </property>
-         </widget>
-        </item>
-        <item row="0" column="0" colspan="2" >
-         <widget class="QComboBox" name="pageGroup" />
-        </item>
-       </layout>
-      </widget>
-     </item>
-     <item>
-      <widget class="QGroupBox" name="groupBox_2" >
-       <property name="title" >
-        <string>Scaling</string>
-       </property>
-       <layout class="QHBoxLayout" >
-        <property name="spacing" >
-         <number>6</number>
-        </property>
-        <property name="margin" >
-         <number>8</number>
-        </property>
-        <item>
-         <widget class="QLabel" name="label" >
-          <property name="text" >
-           <string>Space</string>
-          </property>
-          <property name="textFormat" >
-           <enum>Qt::PlainText</enum>
-          </property>
-          <property name="buddy" >
-           <cstring>spatiumEntry</cstring>
-          </property>
-         </widget>
-        </item>
-        <item>
-         <widget class="QDoubleSpinBox" name="spatiumEntry" >
-          <property name="sizePolicy" >
-           <sizepolicy vsizetype="Fixed" hsizetype="Minimum" >
-            <horstretch>0</horstretch>
-            <verstretch>0</verstretch>
-           </sizepolicy>
-          </property>
-          <property name="decimals" >
-           <number>3</number>
-          </property>
-          <property name="minimum" >
-           <double>0.001000000000000</double>
-          </property>
-          <property name="maximum" >
-           <double>999.990000000000009</double>
-          </property>
-          <property name="singleStep" >
-           <double>0.200000000000000</double>
-          </property>
-          <property name="value" >
-           <double>2.001000000000000</double>
-          </property>
-         </widget>
-        </item>
-       </layout>
-      </widget>
-     </item>
-     <item>
-      <layout class="QVBoxLayout" >
-       <property name="spacing" >
-        <number>6</number>
-       </property>
-       <property name="margin" >
-        <number>8</number>
-       </property>
-       <item>
-        <widget class="QRadioButton" name="mmButton" >
-         <property name="text" >
-          <string>mm</string>
-         </property>
-        </widget>
-       </item>
-       <item>
-        <widget class="QRadioButton" name="inchButton" >
-         <property name="text" >
-          <string>inch</string>
-         </property>
-        </widget>
-       </item>
-      </layout>
-     </item>
-    </layout>
-   </item>
-   <item row="0" column="1" >
-    <layout class="QVBoxLayout" >
-     <property name="spacing" >
-      <number>6</number>
-     </property>
-     <property name="margin" >
-      <number>0</number>
-     </property>
-     <item>
-      <widget class="QGroupBox" name="groupBox_3" >
-       <property name="title" >
-        <string>Even Page Margins</string>
-       </property>
-       <layout class="QGridLayout" >
-        <property name="margin" >
-         <number>8</number>
-        </property>
-        <property name="spacing" >
-         <number>6</number>
-        </property>
-        <item row="3" column="1" >
-         <widget class="QDoubleSpinBox" name="evenPageBottomMargin" >
-          <property name="sizePolicy" >
-           <sizepolicy vsizetype="Fixed" hsizetype="Preferred" >
-            <horstretch>0</horstretch>
-            <verstretch>0</verstretch>
-           </sizepolicy>
-          </property>
-          <property name="maximum" >
-           <double>2000.000000000000000</double>
-          </property>
-         </widget>
-        </item>
-        <item row="2" column="1" >
-         <widget class="QDoubleSpinBox" name="evenPageTopMargin" >
-          <property name="sizePolicy" >
-           <sizepolicy vsizetype="Fixed" hsizetype="Preferred" >
-            <horstretch>0</horstretch>
-            <verstretch>0</verstretch>
-           </sizepolicy>
-          </property>
-          <property name="maximum" >
-           <double>2000.000000000000000</double>
-          </property>
-         </widget>
-        </item>
-        <item row="1" column="1" >
-         <widget class="QDoubleSpinBox" name="evenPageRightMargin" >
-          <property name="sizePolicy" >
-           <sizepolicy vsizetype="Fixed" hsizetype="Preferred" >
-            <horstretch>0</horstretch>
-            <verstretch>0</verstretch>
-           </sizepolicy>
-          </property>
-          <property name="maximum" >
-           <double>2000.000000000000000</double>
-          </property>
-         </widget>
-        </item>
-        <item row="0" column="1" >
-         <widget class="QDoubleSpinBox" name="evenPageLeftMargin" >
-          <property name="sizePolicy" >
-           <sizepolicy vsizetype="Fixed" hsizetype="Fixed" >
-            <horstretch>0</horstretch>
-            <verstretch>0</verstretch>
-           </sizepolicy>
-          </property>
-          <property name="maximum" >
-           <double>2000.000000000000000</double>
-          </property>
-         </widget>
-        </item>
-        <item row="3" column="0" >
-         <widget class="QLabel" name="label_7" >
-          <property name="text" >
-           <string>Bottom Margin</string>
-          </property>
-          <property name="textFormat" >
-           <enum>Qt::PlainText</enum>
-          </property>
-          <property name="buddy" >
-           <cstring>evenPageBottomMargin</cstring>
-          </property>
-         </widget>
-        </item>
-        <item row="2" column="0" >
-         <widget class="QLabel" name="label_6" >
-          <property name="text" >
-           <string>Top Margin</string>
-          </property>
-          <property name="textFormat" >
-           <enum>Qt::PlainText</enum>
-          </property>
-          <property name="buddy" >
-           <cstring>evenPageTopMargin</cstring>
-          </property>
-         </widget>
-        </item>
-        <item row="1" column="0" >
-         <widget class="QLabel" name="label_5" >
-          <property name="text" >
-           <string>Right Margin</string>
-          </property>
-          <property name="textFormat" >
-           <enum>Qt::PlainText</enum>
-          </property>
-          <property name="buddy" >
-           <cstring>evenPageRightMargin</cstring>
-          </property>
-         </widget>
-        </item>
-        <item row="0" column="0" >
-         <widget class="QLabel" name="label_4" >
-          <property name="text" >
-           <string>Left Margin</string>
-          </property>
-          <property name="textFormat" >
-           <enum>Qt::PlainText</enum>
-          </property>
-          <property name="buddy" >
-           <cstring>evenPageLeftMargin</cstring>
-          </property>
-         </widget>
-        </item>
-       </layout>
-      </widget>
-     </item>
-     <item>
-      <widget class="QGroupBox" name="groupBox_4" >
-       <property name="title" >
-        <string>Odd Page Margins</string>
-       </property>
-       <layout class="QGridLayout" >
-        <property name="margin" >
-         <number>8</number>
-        </property>
-        <property name="spacing" >
-         <number>6</number>
-        </property>
-        <item row="3" column="1" >
-         <widget class="QDoubleSpinBox" name="oddPageBottomMargin" >
-          <property name="sizePolicy" >
-           <sizepolicy vsizetype="Fixed" hsizetype="Preferred" >
-            <horstretch>0</horstretch>
-            <verstretch>0</verstretch>
-           </sizepolicy>
-          </property>
-          <property name="maximum" >
-           <double>2000.000000000000000</double>
-          </property>
-         </widget>
-        </item>
-        <item row="2" column="1" >
-         <widget class="QDoubleSpinBox" name="oddPageTopMargin" >
-          <property name="sizePolicy" >
-           <sizepolicy vsizetype="Fixed" hsizetype="Preferred" >
-            <horstretch>0</horstretch>
-            <verstretch>0</verstretch>
-           </sizepolicy>
-          </property>
-          <property name="maximum" >
-           <double>2000.000000000000000</double>
-          </property>
-         </widget>
-        </item>
-        <item row="1" column="1" >
-         <widget class="QDoubleSpinBox" name="oddPageRightMargin" >
-          <property name="sizePolicy" >
-           <sizepolicy vsizetype="Fixed" hsizetype="Preferred" >
-            <horstretch>0</horstretch>
-            <verstretch>0</verstretch>
-           </sizepolicy>
-          </property>
-          <property name="maximum" >
-           <double>2000.000000000000000</double>
-          </property>
-         </widget>
-        </item>
-        <item row="0" column="1" >
-         <widget class="QDoubleSpinBox" name="oddPageLeftMargin" >
-          <property name="sizePolicy" >
-           <sizepolicy vsizetype="Fixed" hsizetype="Fixed" >
-            <horstretch>0</horstretch>
-            <verstretch>0</verstretch>
-           </sizepolicy>
-          </property>
-          <property name="maximum" >
-           <double>2000.000000000000000</double>
-          </property>
-         </widget>
-        </item>
-        <item row="3" column="0" >
-         <widget class="QLabel" name="label_11" >
-          <property name="text" >
-           <string>Bottom Margin</string>
-          </property>
-          <property name="textFormat" >
-           <enum>Qt::PlainText</enum>
-          </property>
-          <property name="buddy" >
-           <cstring>oddPageBottomMargin</cstring>
-          </property>
-         </widget>
-        </item>
-        <item row="2" column="0" >
-         <widget class="QLabel" name="label_10" >
-          <property name="text" >
-           <string>Top Margin</string>
-          </property>
-          <property name="textFormat" >
-           <enum>Qt::PlainText</enum>
-          </property>
-          <property name="buddy" >
-           <cstring>oddPageTopMargin</cstring>
-          </property>
-         </widget>
-        </item>
-        <item row="1" column="0" >
-         <widget class="QLabel" name="label_9" >
-          <property name="text" >
-           <string>Right Margin</string>
-          </property>
-          <property name="textFormat" >
-           <enum>Qt::PlainText</enum>
-          </property>
-          <property name="buddy" >
-           <cstring>oddPageRightMargin</cstring>
-          </property>
-         </widget>
-        </item>
-        <item row="0" column="0" >
-         <widget class="QLabel" name="label_8" >
-          <property name="text" >
-           <string>Left Margin</string>
-          </property>
-          <property name="textFormat" >
-           <enum>Qt::PlainText</enum>
-          </property>
-          <property name="buddy" >
-           <cstring>oddPageLeftMargin</cstring>
-          </property>
-         </widget>
-        </item>
-       </layout>
-      </widget>
-     </item>
-    </layout>
-   </item>
-  </layout>
- </widget>
- <tabstops>
-  <tabstop>buttonApply</tabstop>
-  <tabstop>buttonOk</tabstop>
-  <tabstop>buttonCancel</tabstop>
-  <tabstop>pageGroup</tabstop>
-  <tabstop>pageWidth</tabstop>
-  <tabstop>pageHeight</tabstop>
-  <tabstop>landscape</tabstop>
-  <tabstop>twosided</tabstop>
-  <tabstop>spatiumEntry</tabstop>
-  <tabstop>mmButton</tabstop>
-  <tabstop>inchButton</tabstop>
-  <tabstop>evenPageLeftMargin</tabstop>
-  <tabstop>evenPageRightMargin</tabstop>
-  <tabstop>evenPageTopMargin</tabstop>
-  <tabstop>evenPageBottomMargin</tabstop>
-  <tabstop>oddPageLeftMargin</tabstop>
-  <tabstop>oddPageRightMargin</tabstop>
-  <tabstop>oddPageTopMargin</tabstop>
-  <tabstop>oddPageBottomMargin</tabstop>
- </tabstops>
- <resources/>
- <connections>
-  <connection>
-   <sender>buttonOk</sender>
-   <signal>clicked()</signal>
-   <receiver>PageSettingsBase</receiver>
-   <slot>accept()</slot>
-   <hints>
-    <hint type="sourcelabel" >
-     <x>278</x>
-     <y>253</y>
-    </hint>
-    <hint type="destinationlabel" >
-     <x>96</x>
-     <y>254</y>
-    </hint>
-   </hints>
-  </connection>
-  <connection>
-   <sender>buttonCancel</sender>
-   <signal>clicked()</signal>
-   <receiver>PageSettingsBase</receiver>
-   <slot>reject()</slot>
-   <hints>
-    <hint type="sourcelabel" >
-     <x>369</x>
-     <y>253</y>
-    </hint>
-    <hint type="destinationlabel" >
-     <x>179</x>
-     <y>282</y>
-    </hint>
-   </hints>
-  </connection>
- </connections>
-</ui>
+<?xml version="1.0" encoding="UTF-8"?>
+<ui version="4.0">
+ <class>PageSettingsBase</class>
+ <widget class="QDialog" name="PageSettingsBase">
+  <property name="geometry">
+   <rect>
+    <x>0</x>
+    <y>0</y>
+    <width>777</width>
+    <height>436</height>
+   </rect>
+  </property>
+  <property name="windowTitle">
+   <string>MuseScore: Page Settings</string>
+  </property>
+  <layout class="QGridLayout">
+   <property name="margin">
+    <number>8</number>
+   </property>
+   <property name="spacing">
+    <number>6</number>
+   </property>
+   <item row="0" column="2">
+    <widget class="QGroupBox" name="previewGroup">
+     <property name="sizePolicy">
+      <sizepolicy hsizetype="Expanding" vsizetype="Expanding">
+       <horstretch>0</horstretch>
+       <verstretch>0</verstretch>
+      </sizepolicy>
+     </property>
+     <property name="title">
+      <string>Preview</string>
+     </property>
+    </widget>
+   </item>
+   <item row="1" column="0" colspan="3">
+    <layout class="QHBoxLayout">
+     <property name="spacing">
+      <number>6</number>
+     </property>
+     <property name="margin">
+      <number>0</number>
+     </property>
+     <item>
+      <spacer>
+       <property name="orientation">
+        <enum>Qt::Horizontal</enum>
+       </property>
+       <property name="sizeHint" stdset="0">
+        <size>
+         <width>131</width>
+         <height>31</height>
+        </size>
+       </property>
+      </spacer>
+     </item>
+     <item>
+      <widget class="QPushButton" name="buttonApply">
+       <property name="text">
+        <string>Apply</string>
+       </property>
+      </widget>
+     </item>
+     <item>
+      <widget class="QPushButton" name="buttonOk">
+       <property name="text">
+        <string>OK</string>
+       </property>
+      </widget>
+     </item>
+     <item>
+      <widget class="QPushButton" name="buttonCancel">
+       <property name="text">
+        <string>Cancel</string>
+       </property>
+      </widget>
+     </item>
+    </layout>
+   </item>
+   <item row="0" column="0">
+    <layout class="QVBoxLayout">
+     <property name="spacing">
+      <number>6</number>
+     </property>
+     <property name="margin">
+      <number>0</number>
+     </property>
+     <item>
+      <widget class="QGroupBox" name="groupBox">
+       <property name="title">
+        <string>Page Size</string>
+       </property>
+       <layout class="QGridLayout">
+        <property name="margin">
+         <number>8</number>
+        </property>
+        <property name="spacing">
+         <number>6</number>
+        </property>
+        <item row="1" column="1">
+         <widget class="QDoubleSpinBox" name="pageWidth">
+          <property name="sizePolicy">
+           <sizepolicy hsizetype="Minimum" vsizetype="Fixed">
+            <horstretch>0</horstretch>
+            <verstretch>0</verstretch>
+           </sizepolicy>
+          </property>
+          <property name="maximum">
+           <double>2000.000000000000000</double>
+          </property>
+         </widget>
+        </item>
+        <item row="2" column="1">
+         <widget class="QDoubleSpinBox" name="pageHeight">
+          <property name="sizePolicy">
+           <sizepolicy hsizetype="Minimum" vsizetype="Fixed">
+            <horstretch>0</horstretch>
+            <verstretch>0</verstretch>
+           </sizepolicy>
+          </property>
+          <property name="maximum">
+           <double>2000.000000000000000</double>
+          </property>
+         </widget>
+        </item>
+        <item row="4" column="0" colspan="2">
+         <widget class="QCheckBox" name="twosided">
+          <property name="text">
+           <string>Two Sided</string>
+          </property>
+         </widget>
+        </item>
+        <item row="3" column="0" colspan="2">
+         <widget class="QCheckBox" name="landscape">
+          <property name="text">
+           <string>Landscape</string>
+          </property>
+         </widget>
+        </item>
+        <item row="2" column="0">
+         <widget class="QLabel" name="label_3">
+          <property name="text">
+           <string>Height</string>
+          </property>
+          <property name="textFormat">
+           <enum>Qt::PlainText</enum>
+          </property>
+          <property name="buddy">
+           <cstring>pageHeight</cstring>
+          </property>
+         </widget>
+        </item>
+        <item row="1" column="0">
+         <widget class="QLabel" name="label_2">
+          <property name="text">
+           <string>Width</string>
+          </property>
+          <property name="textFormat">
+           <enum>Qt::PlainText</enum>
+          </property>
+          <property name="buddy">
+           <cstring>pageWidth</cstring>
+          </property>
+         </widget>
+        </item>
+        <item row="0" column="0" colspan="2">
+         <widget class="QComboBox" name="pageGroup"/>
+        </item>
+       </layout>
+      </widget>
+     </item>
+     <item>
+      <widget class="QGroupBox" name="groupBox_2">
+       <property name="title">
+        <string>Scaling</string>
+       </property>
+       <layout class="QHBoxLayout">
+        <property name="spacing">
+         <number>6</number>
+        </property>
+        <property name="margin">
+         <number>8</number>
+        </property>
+        <item>
+         <widget class="QLabel" name="label">
+          <property name="text">
+           <string>Space</string>
+          </property>
+          <property name="textFormat">
+           <enum>Qt::PlainText</enum>
+          </property>
+          <property name="buddy">
+           <cstring>spatiumEntry</cstring>
+          </property>
+         </widget>
+        </item>
+        <item>
+         <widget class="QDoubleSpinBox" name="spatiumEntry">
+          <property name="sizePolicy">
+           <sizepolicy hsizetype="Minimum" vsizetype="Fixed">
+            <horstretch>0</horstretch>
+            <verstretch>0</verstretch>
+           </sizepolicy>
+          </property>
+          <property name="decimals">
+           <number>3</number>
+          </property>
+          <property name="minimum">
+           <double>0.001000000000000</double>
+          </property>
+          <property name="maximum">
+           <double>999.990000000000009</double>
+          </property>
+          <property name="singleStep">
+           <double>0.200000000000000</double>
+          </property>
+          <property name="value">
+           <double>2.001000000000000</double>
+          </property>
+         </widget>
+        </item>
+       </layout>
+      </widget>
+     </item>
+     <item>
+      <layout class="QHBoxLayout" name="horizontalLayout_2">
+       <item>
+        <widget class="QLabel" name="label_12">
+         <property name="text">
+          <string>First page no.</string>
+         </property>
+         <property name="textFormat">
+          <enum>Qt::PlainText</enum>
+         </property>
+         <property name="buddy">
+          <cstring>pageOffsetEntry</cstring>
+         </property>
+        </widget>
+       </item>
+       <item>
+        <widget class="QSpinBox" name="pageOffsetEntry">
+         <property name="minimum">
+          <number>1</number>
+         </property>
+         <property name="maximum">
+          <number>999</number>
+         </property>
+        </widget>
+       </item>
+      </layout>
+     </item>
+     <item>
+      <layout class="QVBoxLayout">
+       <property name="spacing">
+        <number>6</number>
+       </property>
+       <property name="margin">
+        <number>8</number>
+       </property>
+       <item>
+        <widget class="QRadioButton" name="mmButton">
+         <property name="text">
+          <string>mm</string>
+         </property>
+        </widget>
+       </item>
+       <item>
+        <widget class="QRadioButton" name="inchButton">
+         <property name="text">
+          <string>inch</string>
+         </property>
+        </widget>
+       </item>
+      </layout>
+     </item>
+    </layout>
+   </item>
+   <item row="0" column="1">
+    <layout class="QVBoxLayout">
+     <property name="spacing">
+      <number>6</number>
+     </property>
+     <property name="margin">
+      <number>0</number>
+     </property>
+     <item>
+      <widget class="QGroupBox" name="groupBox_3">
+       <property name="title">
+        <string>Even Page Margins</string>
+       </property>
+       <layout class="QGridLayout">
+        <property name="margin">
+         <number>8</number>
+        </property>
+        <property name="spacing">
+         <number>6</number>
+        </property>
+        <item row="3" column="1">
+         <widget class="QDoubleSpinBox" name="evenPageBottomMargin">
+          <property name="sizePolicy">
+           <sizepolicy hsizetype="Preferred" vsizetype="Fixed">
+            <horstretch>0</horstretch>
+            <verstretch>0</verstretch>
+           </sizepolicy>
+          </property>
+          <property name="maximum">
+           <double>2000.000000000000000</double>
+          </property>
+         </widget>
+        </item>
+        <item row="2" column="1">
+         <widget class="QDoubleSpinBox" name="evenPageTopMargin">
+          <property name="sizePolicy">
+           <sizepolicy hsizetype="Preferred" vsizetype="Fixed">
+            <horstretch>0</horstretch>
+            <verstretch>0</verstretch>
+           </sizepolicy>
+          </property>
+          <property name="maximum">
+           <double>2000.000000000000000</double>
+          </property>
+         </widget>
+        </item>
+        <item row="1" column="1">
+         <widget class="QDoubleSpinBox" name="evenPageRightMargin">
+          <property name="sizePolicy">
+           <sizepolicy hsizetype="Preferred" vsizetype="Fixed">
+            <horstretch>0</horstretch>
+            <verstretch>0</verstretch>
+           </sizepolicy>
+          </property>
+          <property name="maximum">
+           <double>2000.000000000000000</double>
+          </property>
+         </widget>
+        </item>
+        <item row="0" column="1">
+         <widget class="QDoubleSpinBox" name="evenPageLeftMargin">
+          <property name="sizePolicy">
+           <sizepolicy hsizetype="Fixed" vsizetype="Fixed">
+            <horstretch>0</horstretch>
+            <verstretch>0</verstretch>
+           </sizepolicy>
+          </property>
+          <property name="maximum">
+           <double>2000.000000000000000</double>
+          </property>
+         </widget>
+        </item>
+        <item row="3" column="0">
+         <widget class="QLabel" name="label_7">
+          <property name="text">
+           <string>Bottom Margin</string>
+          </property>
+          <property name="textFormat">
+           <enum>Qt::PlainText</enum>
+          </property>
+          <property name="buddy">
+           <cstring>evenPageBottomMargin</cstring>
+          </property>
+         </widget>
+        </item>
+        <item row="2" column="0">
+         <widget class="QLabel" name="label_6">
+          <property name="text">
+           <string>Top Margin</string>
+          </property>
+          <property name="textFormat">
+           <enum>Qt::PlainText</enum>
+          </property>
+          <property name="buddy">
+           <cstring>evenPageTopMargin</cstring>
+          </property>
+         </widget>
+        </item>
+        <item row="1" column="0">
+         <widget class="QLabel" name="label_5">
+          <property name="text">
+           <string>Right Margin</string>
+          </property>
+          <property name="textFormat">
+           <enum>Qt::PlainText</enum>
+          </property>
+          <property name="buddy">
+           <cstring>evenPageRightMargin</cstring>
+          </property>
+         </widget>
+        </item>
+        <item row="0" column="0">
+         <widget class="QLabel" name="label_4">
+          <property name="text">
+           <string>Left Margin</string>
+          </property>
+          <property name="textFormat">
+           <enum>Qt::PlainText</enum>
+          </property>
+          <property name="buddy">
+           <cstring>evenPageLeftMargin</cstring>
+          </property>
+         </widget>
+        </item>
+       </layout>
+      </widget>
+     </item>
+     <item>
+      <widget class="QGroupBox" name="groupBox_4">
+       <property name="title">
+        <string>Odd Page Margins</string>
+       </property>
+       <layout class="QGridLayout">
+        <property name="margin">
+         <number>8</number>
+        </property>
+        <property name="spacing">
+         <number>6</number>
+        </property>
+        <item row="3" column="1">
+         <widget class="QDoubleSpinBox" name="oddPageBottomMargin">
+          <property name="sizePolicy">
+           <sizepolicy hsizetype="Preferred" vsizetype="Fixed">
+            <horstretch>0</horstretch>
+            <verstretch>0</verstretch>
+           </sizepolicy>
+          </property>
+          <property name="maximum">
+           <double>2000.000000000000000</double>
+          </property>
+         </widget>
+        </item>
+        <item row="2" column="1">
+         <widget class="QDoubleSpinBox" name="oddPageTopMargin">
+          <property name="sizePolicy">
+           <sizepolicy hsizetype="Preferred" vsizetype="Fixed">
+            <horstretch>0</horstretch>
+            <verstretch>0</verstretch>
+           </sizepolicy>
+          </property>
+          <property name="maximum">
+           <double>2000.000000000000000</double>
+          </property>
+         </widget>
+        </item>
+        <item row="1" column="1">
+         <widget class="QDoubleSpinBox" name="oddPageRightMargin">
+          <property name="sizePolicy">
+           <sizepolicy hsizetype="Preferred" vsizetype="Fixed">
+            <horstretch>0</horstretch>
+            <verstretch>0</verstretch>
+           </sizepolicy>
+          </property>
+          <property name="maximum">
+           <double>2000.000000000000000</double>
+          </property>
+         </widget>
+        </item>
+        <item row="0" column="1">
+         <widget class="QDoubleSpinBox" name="oddPageLeftMargin">
+          <property name="sizePolicy">
+           <sizepolicy hsizetype="Fixed" vsizetype="Fixed">
+            <horstretch>0</horstretch>
+            <verstretch>0</verstretch>
+           </sizepolicy>
+          </property>
+          <property name="maximum">
+           <double>2000.000000000000000</double>
+          </property>
+         </widget>
+        </item>
+        <item row="3" column="0">
+         <widget class="QLabel" name="label_11">
+          <property name="text">
+           <string>Bottom Margin</string>
+          </property>
+          <property name="textFormat">
+           <enum>Qt::PlainText</enum>
+          </property>
+          <property name="buddy">
+           <cstring>oddPageBottomMargin</cstring>
+          </property>
+         </widget>
+        </item>
+        <item row="2" column="0">
+         <widget class="QLabel" name="label_10">
+          <property name="text">
+           <string>Top Margin</string>
+          </property>
+          <property name="textFormat">
+           <enum>Qt::PlainText</enum>
+          </property>
+          <property name="buddy">
+           <cstring>oddPageTopMargin</cstring>
+          </property>
+         </widget>
+        </item>
+        <item row="1" column="0">
+         <widget class="QLabel" name="label_9">
+          <property name="text">
+           <string>Right Margin</string>
+          </property>
+          <property name="textFormat">
+           <enum>Qt::PlainText</enum>
+          </property>
+          <property name="buddy">
+           <cstring>oddPageRightMargin</cstring>
+          </property>
+         </widget>
+        </item>
+        <item row="0" column="0">
+         <widget class="QLabel" name="label_8">
+          <property name="text">
+           <string>Left Margin</string>
+          </property>
+          <property name="textFormat">
+           <enum>Qt::PlainText</enum>
+          </property>
+          <property name="buddy">
+           <cstring>oddPageLeftMargin</cstring>
+          </property>
+         </widget>
+        </item>
+       </layout>
+      </widget>
+     </item>
+    </layout>
+   </item>
+  </layout>
+ </widget>
+ <tabstops>
+  <tabstop>pageGroup</tabstop>
+  <tabstop>pageWidth</tabstop>
+  <tabstop>pageHeight</tabstop>
+  <tabstop>landscape</tabstop>
+  <tabstop>twosided</tabstop>
+  <tabstop>spatiumEntry</tabstop>
+  <tabstop>pageOffsetEntry</tabstop>
+  <tabstop>mmButton</tabstop>
+  <tabstop>inchButton</tabstop>
+  <tabstop>evenPageLeftMargin</tabstop>
+  <tabstop>evenPageRightMargin</tabstop>
+  <tabstop>evenPageTopMargin</tabstop>
+  <tabstop>evenPageBottomMargin</tabstop>
+  <tabstop>oddPageLeftMargin</tabstop>
+  <tabstop>oddPageRightMargin</tabstop>
+  <tabstop>oddPageTopMargin</tabstop>
+  <tabstop>oddPageBottomMargin</tabstop>
+  <tabstop>buttonApply</tabstop>
+  <tabstop>buttonOk</tabstop>
+  <tabstop>buttonCancel</tabstop>
+ </tabstops>
+ <resources/>
+ <connections>
+  <connection>
+   <sender>buttonOk</sender>
+   <signal>clicked()</signal>
+   <receiver>PageSettingsBase</receiver>
+   <slot>accept()</slot>
+   <hints>
+    <hint type="sourcelabel">
+     <x>278</x>
+     <y>253</y>
+    </hint>
+    <hint type="destinationlabel">
+     <x>96</x>
+     <y>254</y>
+    </hint>
+   </hints>
+  </connection>
+  <connection>
+   <sender>buttonCancel</sender>
+   <signal>clicked()</signal>
+   <receiver>PageSettingsBase</receiver>
+   <slot>reject()</slot>
+   <hints>
+    <hint type="sourcelabel">
+     <x>369</x>
+     <y>253</y>
+    </hint>
+    <hint type="destinationlabel">
+     <x>179</x>
+     <y>282</y>
+    </hint>
+   </hints>
+  </connection>
+ </connections>
+</ui>
Index: mscore/mscore/mscore/score.cpp
===================================================================
--- mscore/mscore/mscore/score.cpp	(revision 3782)
+++ mscore/mscore/mscore/score.cpp	(working copy)
@@ -278,7 +278,7 @@
       _creditsRead    = false;
       _defaultsRead   = false;
       rights          = 0;
-      _pageOffset     = 0;
+//      _pageOffset     = 0;              // moved to PageFormat class (page.h)
       _tempomap       = new AL::TempoMap;
       _sigmap         = new AL::TimeSigMap;
       _sigmap->add(0, Fraction(4, 4));
Index: mscore/mscore/mscore/score.h
===================================================================
--- mscore/mscore/mscore/score.h	(revision 3782)
+++ mscore/mscore/mscore/score.h	(working copy)
@@ -372,7 +372,7 @@
       int curTrack;
 
       TextC* rights;                ///< Copyright printed at bottom of page
-      int _pageOffset;              ///< Offset for page numbers.
+//      int _pageOffset;              // moved to PageFormat (page.h)
 
       void cmdAppendMeasures(int);
       void cmdInsertMeasures(int);
